@@ -11,7 +11,7 @@ DEFAULT_CONFIG_NAME = 'autoscaler_default'
 launch_config_attrs = [
     "image_id", "key_name", "security_groups", "user_data", "instance_type",
     "kernel_id", "ramdisk_id", "block_device_mappings", "instance_monitoring",
-    "instance_profile_name", "spot_price"
+    "instance_profile_name", "spot_price", "ebs_optimized",
 ]
 empty_launch_config_attrs = OrderedDict()
 for attr_name in launch_config_attrs:
